Class: Aws::AppIntegrationsService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AppIntegrationsService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-appintegrationsservice/client.rb,
sig/client.rbs
Overview
An API client for AppIntegrationsService. To construct a client, you need to configure a :region and :credentials.
client = Aws::AppIntegrationsService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateApplicationResponseSuccess, _CreateDataIntegrationAssociationResponseSuccess, _CreateDataIntegrationResponseSuccess, _CreateEventIntegrationResponseSuccess, _DeleteApplicationResponseSuccess, _DeleteDataIntegrationResponseSuccess, _DeleteEventIntegrationResponseSuccess, _GetApplicationResponseSuccess, _GetDataIntegrationResponseSuccess, _GetEventIntegrationResponseSuccess, _ListApplicationAssociationsResponseSuccess, _ListApplicationsResponseSuccess, _ListDataIntegrationAssociationsResponseSuccess, _ListDataIntegrationsResponseSuccess, _ListEventIntegrationAssociationsResponseSuccess, _ListEventIntegrationsResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateApplicationResponseSuccess, _UpdateDataIntegrationAssociationResponseSuccess, _UpdateDataIntegrationResponseSuccess, _UpdateEventIntegrationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates and persists an Application resource.
-
#create_data_integration(params = {}) ⇒ Types::CreateDataIntegrationResponse
Creates and persists a DataIntegration resource.
-
#create_data_integration_association(params = {}) ⇒ Types::CreateDataIntegrationAssociationResponse
Creates and persists a DataIntegrationAssociation resource.
-
#create_event_integration(params = {}) ⇒ Types::CreateEventIntegrationResponse
Creates an EventIntegration, given a specified name, description, and a reference to an Amazon EventBridge bus in your account and a partner event source that pushes events to that bus.
-
#delete_application(params = {}) ⇒ Struct
Deletes an application.
-
#delete_data_integration(params = {}) ⇒ Struct
Deletes the DataIntegration.
-
#delete_event_integration(params = {}) ⇒ Struct
Deletes the specified existing event integration.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Get an Application resource.
-
#get_data_integration(params = {}) ⇒ Types::GetDataIntegrationResponse
Returns information about the DataIntegration.
-
#get_event_integration(params = {}) ⇒ Types::GetEventIntegrationResponse
Returns information about the event integration.
-
#list_application_associations(params = {}) ⇒ Types::ListApplicationAssociationsResponse
Returns a paginated list of application associations for an application.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists applications in the account.
-
#list_data_integration_associations(params = {}) ⇒ Types::ListDataIntegrationAssociationsResponse
Returns a paginated list of DataIntegration associations in the account.
-
#list_data_integrations(params = {}) ⇒ Types::ListDataIntegrationsResponse
Returns a paginated list of DataIntegrations in the account.
-
#list_event_integration_associations(params = {}) ⇒ Types::ListEventIntegrationAssociationsResponse
Returns a paginated list of event integration associations in the account.
-
#list_event_integrations(params = {}) ⇒ Types::ListEventIntegrationsResponse
Returns a paginated list of event integrations in the account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
-
#update_application(params = {}) ⇒ Struct
Updates and persists an Application resource.
-
#update_data_integration(params = {}) ⇒ Struct
Updates the description of a DataIntegration.
-
#update_data_integration_association(params = {}) ⇒ Struct
Updates and persists a DataIntegrationAssociation resource.
-
#update_event_integration(params = {}) ⇒ Struct
Updates the description of an event integration.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1906 1907 1908 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1906 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1909 1910 1911 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1909 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1879 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AppIntegrationsService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-appintegrationsservice' context[:gem_version] = '1.75.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates and persists an Application resource.
87 |
# File 'sig/client.rbs', line 87 def create_application: ( |
#create_data_integration(params = {}) ⇒ Types::CreateDataIntegrationResponse
Creates and persists a DataIntegration resource.
CreateDataIntegration API.
147 |
# File 'sig/client.rbs', line 147 def create_data_integration: ( |
#create_data_integration_association(params = {}) ⇒ Types::CreateDataIntegrationAssociationResponse
Creates and persists a DataIntegrationAssociation resource.
173 |
# File 'sig/client.rbs', line 173 def create_data_integration_association: ( |
#create_event_integration(params = {}) ⇒ Types::CreateEventIntegrationResponse
Creates an EventIntegration, given a specified name, description, and a reference to an Amazon EventBridge bus in your account and a partner event source that pushes events to that bus. No objects are created in the your account, only metadata that is persisted on the EventIntegration control plane.
189 |
# File 'sig/client.rbs', line 189 def create_event_integration: ( |
#delete_application(params = {}) ⇒ Struct
Deletes an application. If the application has associations, you must
delete them first. Alternatively, use the force option to delete the
application and remove its associations.
205 |
# File 'sig/client.rbs', line 205 def delete_application: ( |
#delete_data_integration(params = {}) ⇒ Struct
Deletes the DataIntegration. Only DataIntegrations that don't have any DataIntegrationAssociations can be deleted. Deleting a DataIntegration also deletes the underlying Amazon AppFlow flow and service linked role.
215 |
# File 'sig/client.rbs', line 215 def delete_data_integration: ( |
#delete_event_integration(params = {}) ⇒ Struct
Deletes the specified existing event integration. If the event integration is associated with clients, the request is rejected.
224 |
# File 'sig/client.rbs', line 224 def delete_event_integration: ( |
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Get an Application resource.
251 |
# File 'sig/client.rbs', line 251 def get_application: ( |
#get_data_integration(params = {}) ⇒ Types::GetDataIntegrationResponse
Returns information about the DataIntegration.
270 |
# File 'sig/client.rbs', line 270 def get_data_integration: ( |
#get_event_integration(params = {}) ⇒ Types::GetEventIntegrationResponse
Returns information about the event integration.
285 |
# File 'sig/client.rbs', line 285 def get_event_integration: ( |
#list_application_associations(params = {}) ⇒ Types::ListApplicationAssociationsResponse
Returns a paginated list of application associations for an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
296 |
# File 'sig/client.rbs', line 296 def list_application_associations: ( |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists applications in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
309 |
# File 'sig/client.rbs', line 309 def list_applications: ( |
#list_data_integration_associations(params = {}) ⇒ Types::ListDataIntegrationAssociationsResponse
Returns a paginated list of DataIntegration associations in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
322 |
# File 'sig/client.rbs', line 322 def list_data_integration_associations: ( |
#list_data_integrations(params = {}) ⇒ Types::ListDataIntegrationsResponse
Returns a paginated list of DataIntegrations in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
335 |
# File 'sig/client.rbs', line 335 def list_data_integrations: ( |
#list_event_integration_associations(params = {}) ⇒ Types::ListEventIntegrationAssociationsResponse
Returns a paginated list of event integration associations in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
347 |
# File 'sig/client.rbs', line 347 def list_event_integration_associations: ( |
#list_event_integrations(params = {}) ⇒ Types::ListEventIntegrationsResponse
Returns a paginated list of event integrations in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
360 |
# File 'sig/client.rbs', line 360 def list_event_integrations: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
371 |
# File 'sig/client.rbs', line 371 def list_tags_for_resource: ( |
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
380 |
# File 'sig/client.rbs', line 380 def tag_resource: ( |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
390 |
# File 'sig/client.rbs', line 390 def untag_resource: ( |
#update_application(params = {}) ⇒ Struct
Updates and persists an Application resource.
400 |
# File 'sig/client.rbs', line 400 def update_application: ( |
#update_data_integration(params = {}) ⇒ Struct
Updates the description of a DataIntegration.
447 |
# File 'sig/client.rbs', line 447 def update_data_integration: ( |
#update_data_integration_association(params = {}) ⇒ Struct
Updates and persists a DataIntegrationAssociation resource.
458 |
# File 'sig/client.rbs', line 458 def update_data_integration_association: ( |
#update_event_integration(params = {}) ⇒ Struct
Updates the description of an event integration.
469 |
# File 'sig/client.rbs', line 469 def update_event_integration: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1899 1900 1901 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1899 def waiter_names [] end |