Class: Aws::AppIntegrationsService::Types::CreateApplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppIntegrationsService::Types::CreateApplicationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appintegrationsservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_config ⇒ Types::ApplicationConfig
The configuration settings for the application.
-
#application_source_config ⇒ Types::ApplicationSourceConfig
The configuration for where the application should be loaded from.
-
#application_type ⇒ String
The type of application.
-
#auth_config ⇒ Types::AuthConfig
The authentication settings that Connect Customer uses when calling the external application.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
The description of the application.
-
#iframe_config ⇒ Types::IframeConfig
The iframe configuration for the application.
-
#initialization_timeout ⇒ Integer
The maximum time in milliseconds allowed to establish a connection with the workspace.
-
#is_service ⇒ Boolean
Indicates whether the application is a service.
-
#name ⇒ String
The name of the application.
-
#namespace ⇒ String
The namespace of the application.
-
#permissions ⇒ Array<String>
The configuration of events or requests that the application has access to.
-
#publications ⇒ Array<Types::Publication>
The events that the application publishes.
-
#subscriptions ⇒ Array<Types::Subscription>
The events that the application subscribes.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#application_config ⇒ Types::ApplicationConfig
The configuration settings for the application.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 257 class CreateApplicationRequest < Struct.new( :name, :namespace, :description, :application_source_config, :subscriptions, :publications, :client_token, :tags, :permissions, :is_service, :initialization_timeout, :application_config, :iframe_config, :application_type, :auth_config) SENSITIVE = [] include Aws::Structure end |
#application_source_config ⇒ Types::ApplicationSourceConfig
The configuration for where the application should be loaded from.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 257 class CreateApplicationRequest < Struct.new( :name, :namespace, :description, :application_source_config, :subscriptions, :publications, :client_token, :tags, :permissions, :is_service, :initialization_timeout, :application_config, :iframe_config, :application_type, :auth_config) SENSITIVE = [] include Aws::Structure end |
#application_type ⇒ String
The type of application.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 257 class CreateApplicationRequest < Struct.new( :name, :namespace, :description, :application_source_config, :subscriptions, :publications, :client_token, :tags, :permissions, :is_service, :initialization_timeout, :application_config, :iframe_config, :application_type, :auth_config) SENSITIVE = [] include Aws::Structure end |
#auth_config ⇒ Types::AuthConfig
The authentication settings that Connect Customer uses when calling the external application.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 257 class CreateApplicationRequest < Struct.new( :name, :namespace, :description, :application_source_config, :subscriptions, :publications, :client_token, :tags, :permissions, :is_service, :initialization_timeout, :application_config, :iframe_config, :application_type, :auth_config) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 257 class CreateApplicationRequest < Struct.new( :name, :namespace, :description, :application_source_config, :subscriptions, :publications, :client_token, :tags, :permissions, :is_service, :initialization_timeout, :application_config, :iframe_config, :application_type, :auth_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the application.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 257 class CreateApplicationRequest < Struct.new( :name, :namespace, :description, :application_source_config, :subscriptions, :publications, :client_token, :tags, :permissions, :is_service, :initialization_timeout, :application_config, :iframe_config, :application_type, :auth_config) SENSITIVE = [] include Aws::Structure end |
#iframe_config ⇒ Types::IframeConfig
The iframe configuration for the application.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 257 class CreateApplicationRequest < Struct.new( :name, :namespace, :description, :application_source_config, :subscriptions, :publications, :client_token, :tags, :permissions, :is_service, :initialization_timeout, :application_config, :iframe_config, :application_type, :auth_config) SENSITIVE = [] include Aws::Structure end |
#initialization_timeout ⇒ Integer
The maximum time in milliseconds allowed to establish a connection with the workspace.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 257 class CreateApplicationRequest < Struct.new( :name, :namespace, :description, :application_source_config, :subscriptions, :publications, :client_token, :tags, :permissions, :is_service, :initialization_timeout, :application_config, :iframe_config, :application_type, :auth_config) SENSITIVE = [] include Aws::Structure end |
#is_service ⇒ Boolean
Indicates whether the application is a service.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 257 class CreateApplicationRequest < Struct.new( :name, :namespace, :description, :application_source_config, :subscriptions, :publications, :client_token, :tags, :permissions, :is_service, :initialization_timeout, :application_config, :iframe_config, :application_type, :auth_config) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the application.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 257 class CreateApplicationRequest < Struct.new( :name, :namespace, :description, :application_source_config, :subscriptions, :publications, :client_token, :tags, :permissions, :is_service, :initialization_timeout, :application_config, :iframe_config, :application_type, :auth_config) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the application.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 257 class CreateApplicationRequest < Struct.new( :name, :namespace, :description, :application_source_config, :subscriptions, :publications, :client_token, :tags, :permissions, :is_service, :initialization_timeout, :application_config, :iframe_config, :application_type, :auth_config) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<String>
The configuration of events or requests that the application has access to.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 257 class CreateApplicationRequest < Struct.new( :name, :namespace, :description, :application_source_config, :subscriptions, :publications, :client_token, :tags, :permissions, :is_service, :initialization_timeout, :application_config, :iframe_config, :application_type, :auth_config) SENSITIVE = [] include Aws::Structure end |
#publications ⇒ Array<Types::Publication>
The events that the application publishes.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 257 class CreateApplicationRequest < Struct.new( :name, :namespace, :description, :application_source_config, :subscriptions, :publications, :client_token, :tags, :permissions, :is_service, :initialization_timeout, :application_config, :iframe_config, :application_type, :auth_config) SENSITIVE = [] include Aws::Structure end |
#subscriptions ⇒ Array<Types::Subscription>
The events that the application subscribes.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 257 class CreateApplicationRequest < Struct.new( :name, :namespace, :description, :application_source_config, :subscriptions, :publications, :client_token, :tags, :permissions, :is_service, :initialization_timeout, :application_config, :iframe_config, :application_type, :auth_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "tags": "key2":"value2" }.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 257 class CreateApplicationRequest < Struct.new( :name, :namespace, :description, :application_source_config, :subscriptions, :publications, :client_token, :tags, :permissions, :is_service, :initialization_timeout, :application_config, :iframe_config, :application_type, :auth_config) SENSITIVE = [] include Aws::Structure end |