Class: Aws::AppIntegrationsService::Types::CreateDataIntegrationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppIntegrationsService::Types::CreateDataIntegrationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appintegrationsservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
A description of the DataIntegration.
-
#file_configuration ⇒ Types::FileConfiguration
The configuration for what files should be pulled from the source.
-
#kms_key ⇒ String
The KMS key ARN for the DataIntegration.
-
#name ⇒ String
The name of the DataIntegration.
-
#object_configuration ⇒ Hash<String,Hash<String,Array<String>>>
The configuration for what data should be pulled from the source.
-
#schedule_config ⇒ Types::ScheduleConfiguration
The name of the data and how often it should be pulled from the source.
-
#source_uri ⇒ String
The URI of the data source.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 416 class CreateDataIntegrationRequest < Struct.new( :name, :description, :kms_key, :source_uri, :schedule_config, :tags, :client_token, :file_configuration, :object_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the DataIntegration.
416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 416 class CreateDataIntegrationRequest < Struct.new( :name, :description, :kms_key, :source_uri, :schedule_config, :tags, :client_token, :file_configuration, :object_configuration) SENSITIVE = [] include Aws::Structure end |
#file_configuration ⇒ Types::FileConfiguration
The configuration for what files should be pulled from the source.
416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 416 class CreateDataIntegrationRequest < Struct.new( :name, :description, :kms_key, :source_uri, :schedule_config, :tags, :client_token, :file_configuration, :object_configuration) SENSITIVE = [] include Aws::Structure end |
#kms_key ⇒ String
The KMS key ARN for the DataIntegration.
416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 416 class CreateDataIntegrationRequest < Struct.new( :name, :description, :kms_key, :source_uri, :schedule_config, :tags, :client_token, :file_configuration, :object_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the DataIntegration.
416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 416 class CreateDataIntegrationRequest < Struct.new( :name, :description, :kms_key, :source_uri, :schedule_config, :tags, :client_token, :file_configuration, :object_configuration) SENSITIVE = [] include Aws::Structure end |
#object_configuration ⇒ Hash<String,Hash<String,Array<String>>>
The configuration for what data should be pulled from the source.
416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 416 class CreateDataIntegrationRequest < Struct.new( :name, :description, :kms_key, :source_uri, :schedule_config, :tags, :client_token, :file_configuration, :object_configuration) SENSITIVE = [] include Aws::Structure end |
#schedule_config ⇒ Types::ScheduleConfiguration
The name of the data and how often it should be pulled from the source.
416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 416 class CreateDataIntegrationRequest < Struct.new( :name, :description, :kms_key, :source_uri, :schedule_config, :tags, :client_token, :file_configuration, :object_configuration) SENSITIVE = [] include Aws::Structure end |
#source_uri ⇒ String
The URI of the data source.
416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 416 class CreateDataIntegrationRequest < Struct.new( :name, :description, :kms_key, :source_uri, :schedule_config, :tags, :client_token, :file_configuration, :object_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "tags": "key2":"value2" }.
416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 416 class CreateDataIntegrationRequest < Struct.new( :name, :description, :kms_key, :source_uri, :schedule_config, :tags, :client_token, :file_configuration, :object_configuration) SENSITIVE = [] include Aws::Structure end |