Class: Aws::AppIntegrationsService::Types::CreateDataIntegrationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appintegrationsservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN)

Returns:

  • (String)


486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 486

class CreateDataIntegrationResponse < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :kms_key,
  :source_uri,
  :schedule_configuration,
  :tags,
  :client_token,
  :file_configuration,
  :object_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

Returns:

  • (String)


486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 486

class CreateDataIntegrationResponse < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :kms_key,
  :source_uri,
  :schedule_configuration,
  :tags,
  :client_token,
  :file_configuration,
  :object_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the DataIntegration.

Returns:

  • (String)


486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 486

class CreateDataIntegrationResponse < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :kms_key,
  :source_uri,
  :schedule_configuration,
  :tags,
  :client_token,
  :file_configuration,
  :object_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#file_configurationTypes::FileConfiguration

The configuration for what files should be pulled from the source.



486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 486

class CreateDataIntegrationResponse < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :kms_key,
  :source_uri,
  :schedule_configuration,
  :tags,
  :client_token,
  :file_configuration,
  :object_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A unique identifier.

Returns:

  • (String)


486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 486

class CreateDataIntegrationResponse < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :kms_key,
  :source_uri,
  :schedule_configuration,
  :tags,
  :client_token,
  :file_configuration,
  :object_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#kms_keyString

The KMS key ARN for the DataIntegration.

Returns:

  • (String)


486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 486

class CreateDataIntegrationResponse < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :kms_key,
  :source_uri,
  :schedule_configuration,
  :tags,
  :client_token,
  :file_configuration,
  :object_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the DataIntegration.

Returns:

  • (String)


486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 486

class CreateDataIntegrationResponse < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :kms_key,
  :source_uri,
  :schedule_configuration,
  :tags,
  :client_token,
  :file_configuration,
  :object_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#object_configurationHash<String,Hash<String,Array<String>>>

The configuration for what data should be pulled from the source.

Returns:

  • (Hash<String,Hash<String,Array<String>>>)


486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 486

class CreateDataIntegrationResponse < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :kms_key,
  :source_uri,
  :schedule_configuration,
  :tags,
  :client_token,
  :file_configuration,
  :object_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_configurationTypes::ScheduleConfiguration

The name of the data and how often it should be pulled from the source.



486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 486

class CreateDataIntegrationResponse < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :kms_key,
  :source_uri,
  :schedule_configuration,
  :tags,
  :client_token,
  :file_configuration,
  :object_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#source_uriString

The URI of the data source.

Returns:

  • (String)


486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 486

class CreateDataIntegrationResponse < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :kms_key,
  :source_uri,
  :schedule_configuration,
  :tags,
  :client_token,
  :file_configuration,
  :object_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 486

class CreateDataIntegrationResponse < Struct.new(
  :arn,
  :id,
  :name,
  :description,
  :kms_key,
  :source_uri,
  :schedule_configuration,
  :tags,
  :client_token,
  :file_configuration,
  :object_configuration)
  SENSITIVE = []
  include Aws::Structure
end