Class: Aws::AppIntegrationsService::Types::CreateEventIntegrationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appintegrationsservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


540
541
542
543
544
545
546
547
548
549
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 540

class CreateEventIntegrationRequest < Struct.new(
  :name,
  :description,
  :event_filter,
  :event_bridge_bus,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the event integration.

Returns:

  • (String)


540
541
542
543
544
545
546
547
548
549
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 540

class CreateEventIntegrationRequest < Struct.new(
  :name,
  :description,
  :event_filter,
  :event_bridge_bus,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#event_bridge_busString

The EventBridge bus.

Returns:

  • (String)


540
541
542
543
544
545
546
547
548
549
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 540

class CreateEventIntegrationRequest < Struct.new(
  :name,
  :description,
  :event_filter,
  :event_bridge_bus,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#event_filterTypes::EventFilter

The event filter.

Returns:



540
541
542
543
544
545
546
547
548
549
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 540

class CreateEventIntegrationRequest < Struct.new(
  :name,
  :description,
  :event_filter,
  :event_bridge_bus,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the event integration.

Returns:

  • (String)


540
541
542
543
544
545
546
547
548
549
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 540

class CreateEventIntegrationRequest < Struct.new(
  :name,
  :description,
  :event_filter,
  :event_bridge_bus,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource. For example, { "tags": "key2":"value2" }.

Returns:

  • (Hash<String,String>)


540
541
542
543
544
545
546
547
548
549
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 540

class CreateEventIntegrationRequest < Struct.new(
  :name,
  :description,
  :event_filter,
  :event_bridge_bus,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end