Class: Aws::AppIntegrationsService::Types::ListDataIntegrationAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppIntegrationsService::Types::ListDataIntegrationAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appintegrationsservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_integration_identifier ⇒ String
A unique identifier for the DataIntegration.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#data_integration_identifier ⇒ String
A unique identifier for the DataIntegration.
1263 1264 1265 1266 1267 1268 1269 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 1263 class ListDataIntegrationAssociationsRequest < Struct.new( :data_integration_identifier, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
1263 1264 1265 1266 1267 1268 1269 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 1263 class ListDataIntegrationAssociationsRequest < Struct.new( :data_integration_identifier, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
1263 1264 1265 1266 1267 1268 1269 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 1263 class ListDataIntegrationAssociationsRequest < Struct.new( :data_integration_identifier, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |