Class: Aws::AppIntegrationsService::Types::ListDataIntegrationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppIntegrationsService::Types::ListDataIntegrationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appintegrationsservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return per page.
1302 1303 1304 1305 1306 1307 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 1302 class ListDataIntegrationsRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
1302 1303 1304 1305 1306 1307 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 1302 class ListDataIntegrationsRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |