Class: Aws::AppIntegrationsService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AppIntegrationsService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-appintegrationsservice/client.rb,
sig/client.rbs
Overview
An API client for AppIntegrationsService. To construct a client, you need to configure a :region and :credentials.
client = Aws::AppIntegrationsService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateApplicationResponseSuccess, _CreateDataIntegrationAssociationResponseSuccess, _CreateDataIntegrationResponseSuccess, _CreateEventIntegrationResponseSuccess, _DeleteApplicationResponseSuccess, _DeleteDataIntegrationResponseSuccess, _DeleteEventIntegrationResponseSuccess, _GetApplicationResponseSuccess, _GetDataIntegrationResponseSuccess, _GetEventIntegrationResponseSuccess, _ListApplicationAssociationsResponseSuccess, _ListApplicationsResponseSuccess, _ListDataIntegrationAssociationsResponseSuccess, _ListDataIntegrationsResponseSuccess, _ListEventIntegrationAssociationsResponseSuccess, _ListEventIntegrationsResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateApplicationResponseSuccess, _UpdateDataIntegrationAssociationResponseSuccess, _UpdateDataIntegrationResponseSuccess, _UpdateEventIntegrationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates and persists an Application resource.
-
#create_data_integration(params = {}) ⇒ Types::CreateDataIntegrationResponse
Creates and persists a DataIntegration resource.
-
#create_data_integration_association(params = {}) ⇒ Types::CreateDataIntegrationAssociationResponse
Creates and persists a DataIntegrationAssociation resource.
-
#create_event_integration(params = {}) ⇒ Types::CreateEventIntegrationResponse
Creates an EventIntegration, given a specified name, description, and a reference to an Amazon EventBridge bus in your account and a partner event source that pushes events to that bus.
-
#delete_application(params = {}) ⇒ Struct
Deletes the Application.
-
#delete_data_integration(params = {}) ⇒ Struct
Deletes the DataIntegration.
-
#delete_event_integration(params = {}) ⇒ Struct
Deletes the specified existing event integration.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Get an Application resource.
-
#get_data_integration(params = {}) ⇒ Types::GetDataIntegrationResponse
Returns information about the DataIntegration.
-
#get_event_integration(params = {}) ⇒ Types::GetEventIntegrationResponse
Returns information about the event integration.
-
#list_application_associations(params = {}) ⇒ Types::ListApplicationAssociationsResponse
Returns a paginated list of application associations for an application.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists applications in the account.
-
#list_data_integration_associations(params = {}) ⇒ Types::ListDataIntegrationAssociationsResponse
Returns a paginated list of DataIntegration associations in the account.
-
#list_data_integrations(params = {}) ⇒ Types::ListDataIntegrationsResponse
Returns a paginated list of DataIntegrations in the account.
-
#list_event_integration_associations(params = {}) ⇒ Types::ListEventIntegrationAssociationsResponse
Returns a paginated list of event integration associations in the account.
-
#list_event_integrations(params = {}) ⇒ Types::ListEventIntegrationsResponse
Returns a paginated list of event integrations in the account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
-
#update_application(params = {}) ⇒ Struct
Updates and persists an Application resource.
-
#update_data_integration(params = {}) ⇒ Struct
Updates the description of a DataIntegration.
-
#update_data_integration_association(params = {}) ⇒ Struct
Updates and persists a DataIntegrationAssociation resource.
-
#update_event_integration(params = {}) ⇒ Struct
Updates the description of an event integration.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1874 1875 1876 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1874 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1877 1878 1879 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1877 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1847 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AppIntegrationsService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-appintegrationsservice' context[:gem_version] = '1.71.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates and persists an Application resource.
87 |
# File 'sig/client.rbs', line 87
def create_application: (
|
#create_data_integration(params = {}) ⇒ Types::CreateDataIntegrationResponse
Creates and persists a DataIntegration resource.
CreateDataIntegration API.
143 |
# File 'sig/client.rbs', line 143
def create_data_integration: (
|
#create_data_integration_association(params = {}) ⇒ Types::CreateDataIntegrationAssociationResponse
Creates and persists a DataIntegrationAssociation resource.
169 |
# File 'sig/client.rbs', line 169
def create_data_integration_association: (
|
#create_event_integration(params = {}) ⇒ Types::CreateEventIntegrationResponse
Creates an EventIntegration, given a specified name, description, and a reference to an Amazon EventBridge bus in your account and a partner event source that pushes events to that bus. No objects are created in the your account, only metadata that is persisted on the EventIntegration control plane.
185 |
# File 'sig/client.rbs', line 185
def create_event_integration: (
|
#delete_application(params = {}) ⇒ Struct
Deletes the Application. Only Applications that don't have any Application Associations can be deleted.
201 |
# File 'sig/client.rbs', line 201
def delete_application: (
|
#delete_data_integration(params = {}) ⇒ Struct
Deletes the DataIntegration. Only DataIntegrations that don't have any DataIntegrationAssociations can be deleted. Deleting a DataIntegration also deletes the underlying Amazon AppFlow flow and service linked role.
210 |
# File 'sig/client.rbs', line 210
def delete_data_integration: (
|
#delete_event_integration(params = {}) ⇒ Struct
Deletes the specified existing event integration. If the event integration is associated with clients, the request is rejected.
219 |
# File 'sig/client.rbs', line 219
def delete_event_integration: (
|
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Get an Application resource.
245 |
# File 'sig/client.rbs', line 245
def get_application: (
|
#get_data_integration(params = {}) ⇒ Types::GetDataIntegrationResponse
Returns information about the DataIntegration.
264 |
# File 'sig/client.rbs', line 264
def get_data_integration: (
|
#get_event_integration(params = {}) ⇒ Types::GetEventIntegrationResponse
Returns information about the event integration.
279 |
# File 'sig/client.rbs', line 279
def get_event_integration: (
|
#list_application_associations(params = {}) ⇒ Types::ListApplicationAssociationsResponse
Returns a paginated list of application associations for an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
290 |
# File 'sig/client.rbs', line 290
def list_application_associations: (
|
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists applications in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
303 |
# File 'sig/client.rbs', line 303
def list_applications: (
|
#list_data_integration_associations(params = {}) ⇒ Types::ListDataIntegrationAssociationsResponse
Returns a paginated list of DataIntegration associations in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
316 |
# File 'sig/client.rbs', line 316
def list_data_integration_associations: (
|
#list_data_integrations(params = {}) ⇒ Types::ListDataIntegrationsResponse
Returns a paginated list of DataIntegrations in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
329 |
# File 'sig/client.rbs', line 329
def list_data_integrations: (
|
#list_event_integration_associations(params = {}) ⇒ Types::ListEventIntegrationAssociationsResponse
Returns a paginated list of event integration associations in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
341 |
# File 'sig/client.rbs', line 341
def list_event_integration_associations: (
|
#list_event_integrations(params = {}) ⇒ Types::ListEventIntegrationsResponse
Returns a paginated list of event integrations in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
354 |
# File 'sig/client.rbs', line 354
def list_event_integrations: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
365 |
# File 'sig/client.rbs', line 365
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
374 |
# File 'sig/client.rbs', line 374
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
384 |
# File 'sig/client.rbs', line 384
def untag_resource: (
|
#update_application(params = {}) ⇒ Struct
Updates and persists an Application resource.
394 |
# File 'sig/client.rbs', line 394
def update_application: (
|
#update_data_integration(params = {}) ⇒ Struct
Updates the description of a DataIntegration.
437 |
# File 'sig/client.rbs', line 437
def update_data_integration: (
|
#update_data_integration_association(params = {}) ⇒ Struct
Updates and persists a DataIntegrationAssociation resource.
448 |
# File 'sig/client.rbs', line 448
def update_data_integration_association: (
|
#update_event_integration(params = {}) ⇒ Struct
Updates the description of an event integration.
459 |
# File 'sig/client.rbs', line 459
def update_event_integration: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1867 1868 1869 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1867 def waiter_names [] end |