Class: Aws::AppIntegrationsService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AppIntegrationsService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-appintegrationsservice/client.rb
Overview
An API client for AppIntegrationsService. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::AppIntegrationsService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates and persists an Application resource.
-
#create_data_integration(params = {}) ⇒ Types::CreateDataIntegrationResponse
Creates and persists a DataIntegration resource.
-
#create_data_integration_association(params = {}) ⇒ Types::CreateDataIntegrationAssociationResponse
Creates and persists a DataIntegrationAssociation resource.
-
#create_event_integration(params = {}) ⇒ Types::CreateEventIntegrationResponse
Creates an EventIntegration, given a specified name, description, and a reference to an Amazon EventBridge bus in your account and a partner event source that pushes events to that bus.
-
#delete_application(params = {}) ⇒ Struct
Deletes the Application.
-
#delete_data_integration(params = {}) ⇒ Struct
Deletes the DataIntegration.
-
#delete_event_integration(params = {}) ⇒ Struct
Deletes the specified existing event integration.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Get an Application resource.
-
#get_data_integration(params = {}) ⇒ Types::GetDataIntegrationResponse
Returns information about the DataIntegration.
-
#get_event_integration(params = {}) ⇒ Types::GetEventIntegrationResponse
Returns information about the event integration.
-
#list_application_associations(params = {}) ⇒ Types::ListApplicationAssociationsResponse
Returns a paginated list of application associations for an application.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists applications in the account.
-
#list_data_integration_associations(params = {}) ⇒ Types::ListDataIntegrationAssociationsResponse
Returns a paginated list of DataIntegration associations in the account.
-
#list_data_integrations(params = {}) ⇒ Types::ListDataIntegrationsResponse
Returns a paginated list of DataIntegrations in the account.
-
#list_event_integration_associations(params = {}) ⇒ Types::ListEventIntegrationAssociationsResponse
Returns a paginated list of event integration associations in the account.
-
#list_event_integrations(params = {}) ⇒ Types::ListEventIntegrationsResponse
Returns a paginated list of event integrations in the account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
-
#update_application(params = {}) ⇒ Struct
Updates and persists an Application resource.
-
#update_data_integration(params = {}) ⇒ Struct
Updates the description of a DataIntegration.
-
#update_data_integration_association(params = {}) ⇒ Struct
Updates and persists a DataIntegrationAssociation resource.
-
#update_event_integration(params = {}) ⇒ Struct
Updates the description of an event integration.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1874 1875 1876 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1874 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1877 1878 1879 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1877 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1847 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AppIntegrationsService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-appintegrationsservice' context[:gem_version] = '1.69.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates and persists an Application resource.
615 616 617 618 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 615 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_data_integration(params = {}) ⇒ Types::CreateDataIntegrationResponse
Creates and persists a DataIntegration resource.
<note markdown=“1”> You cannot create a DataIntegration association for a DataIntegration that has been previously associated. Use a different DataIntegration, or recreate the DataIntegration using the ‘CreateDataIntegration` API.
</note>
739 740 741 742 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 739 def create_data_integration(params = {}, = {}) req = build_request(:create_data_integration, params) req.send_request() end |
#create_data_integration_association(params = {}) ⇒ Types::CreateDataIntegrationAssociationResponse
Creates and persists a DataIntegrationAssociation resource.
821 822 823 824 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 821 def create_data_integration_association(params = {}, = {}) req = build_request(:create_data_integration_association, params) req.send_request() end |
#create_event_integration(params = {}) ⇒ Types::CreateEventIntegrationResponse
Creates an EventIntegration, given a specified name, description, and a reference to an Amazon EventBridge bus in your account and a partner event source that pushes events to that bus. No objects are created in the your account, only metadata that is persisted on the EventIntegration control plane.
889 890 891 892 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 889 def create_event_integration(params = {}, = {}) req = build_request(:create_event_integration, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes the Application. Only Applications that don’t have any Application Associations can be deleted.
925 926 927 928 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 925 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_data_integration(params = {}) ⇒ Struct
Deletes the DataIntegration. Only DataIntegrations that don’t have any DataIntegrationAssociations can be deleted. Deleting a DataIntegration also deletes the underlying Amazon AppFlow flow and service linked role.
<note markdown=“1”> You cannot create a DataIntegration association for a DataIntegration that has been previously associated. Use a different DataIntegration, or recreate the DataIntegration using the [CreateDataIntegration] API.
</note>
[1]: docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegration.html
961 962 963 964 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 961 def delete_data_integration(params = {}, = {}) req = build_request(:delete_data_integration, params) req.send_request() end |
#delete_event_integration(params = {}) ⇒ Struct
Deletes the specified existing event integration. If the event integration is associated with clients, the request is rejected.
984 985 986 987 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 984 def delete_event_integration(params = {}, = {}) req = build_request(:delete_event_integration, params) req.send_request() end |
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Get an Application resource.
1077 1078 1079 1080 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1077 def get_application(params = {}, = {}) req = build_request(:get_application, params) req.send_request() end |
#get_data_integration(params = {}) ⇒ Types::GetDataIntegrationResponse
Returns information about the DataIntegration.
<note markdown=“1”> You cannot create a DataIntegration association for a DataIntegration that has been previously associated. Use a different DataIntegration, or recreate the DataIntegration using the [CreateDataIntegration] API.
</note>
[1]: docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegration.html
1144 1145 1146 1147 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1144 def get_data_integration(params = {}, = {}) req = build_request(:get_data_integration, params) req.send_request() end |
#get_event_integration(params = {}) ⇒ Types::GetEventIntegrationResponse
Returns information about the event integration.
1183 1184 1185 1186 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1183 def get_event_integration(params = {}, = {}) req = build_request(:get_event_integration, params) req.send_request() end |
#list_application_associations(params = {}) ⇒ Types::ListApplicationAssociationsResponse
Returns a paginated list of application associations for an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1250 1251 1252 1253 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1250 def list_application_associations(params = {}, = {}) req = build_request(:list_application_associations, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists applications in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1322 1323 1324 1325 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1322 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_data_integration_associations(params = {}) ⇒ Types::ListDataIntegrationAssociationsResponse
Returns a paginated list of DataIntegration associations in the account.
<note markdown=“1”> You cannot create a DataIntegration association for a DataIntegration that has been previously associated. Use a different DataIntegration, or recreate the DataIntegration using the [CreateDataIntegration] API.
</note>
[1]: docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegration.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1388 1389 1390 1391 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1388 def list_data_integration_associations(params = {}, = {}) req = build_request(:list_data_integration_associations, params) req.send_request() end |
#list_data_integrations(params = {}) ⇒ Types::ListDataIntegrationsResponse
Returns a paginated list of DataIntegrations in the account.
<note markdown=“1”> You cannot create a DataIntegration association for a DataIntegration that has been previously associated. Use a different DataIntegration, or recreate the DataIntegration using the [CreateDataIntegration] API.
</note>
[1]: docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegration.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1440 1441 1442 1443 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1440 def list_data_integrations(params = {}, = {}) req = build_request(:list_data_integrations, params) req.send_request() end |
#list_event_integration_associations(params = {}) ⇒ Types::ListEventIntegrationAssociationsResponse
Returns a paginated list of event integration associations in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1490 1491 1492 1493 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1490 def list_event_integration_associations(params = {}, = {}) req = build_request(:list_event_integration_associations, params) req.send_request() end |
#list_event_integrations(params = {}) ⇒ Types::ListEventIntegrationsResponse
Returns a paginated list of event integrations in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1535 1536 1537 1538 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1535 def list_event_integrations(params = {}, = {}) req = build_request(:list_event_integrations, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
1564 1565 1566 1567 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1564 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
1594 1595 1596 1597 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1594 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
1620 1621 1622 1623 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1620 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_application(params = {}) ⇒ Struct
Updates and persists an Application resource.
1725 1726 1727 1728 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1725 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_data_integration(params = {}) ⇒ Struct
Updates the description of a DataIntegration.
<note markdown=“1”> You cannot create a DataIntegration association for a DataIntegration that has been previously associated. Use a different DataIntegration, or recreate the DataIntegration using the [CreateDataIntegration] API.
</note>
[1]: docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegration.html
1766 1767 1768 1769 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1766 def update_data_integration(params = {}, = {}) req = build_request(:update_data_integration, params) req.send_request() end |
#update_data_integration_association(params = {}) ⇒ Struct
Updates and persists a DataIntegrationAssociation resource.
<note markdown=“1”> Updating a DataIntegrationAssociation with ExecutionConfiguration will rerun the on-demand job.
</note>
1812 1813 1814 1815 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1812 def update_data_integration_association(params = {}, = {}) req = build_request(:update_data_integration_association, params) req.send_request() end |
#update_event_integration(params = {}) ⇒ Struct
Updates the description of an event integration.
1838 1839 1840 1841 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1838 def update_event_integration(params = {}, = {}) req = build_request(:update_event_integration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1867 1868 1869 |
# File 'lib/aws-sdk-appintegrationsservice/client.rb', line 1867 def waiter_names [] end |