Class: Aws::AppIntegrationsService::Types::AuthConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppIntegrationsService::Types::AuthConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appintegrationsservice/types.rb
Overview
Contains the authentication settings that Connect Customer uses to call an external application endpoint. The configuration includes the authentication type and credential location.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth_type ⇒ String
The type of authentication used when calling the external application.
-
#credential_provider_identifier ⇒ String
The ARN of the Secrets Manager secret that stores the credentials.
Instance Attribute Details
#auth_type ⇒ String
The type of authentication used when calling the external application.
144 145 146 147 148 149 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 144 class AuthConfig < Struct.new( :auth_type, :credential_provider_identifier) SENSITIVE = [] include Aws::Structure end |
#credential_provider_identifier ⇒ String
The ARN of the Secrets Manager secret that stores the credentials. The secret must be accessible to Connect Customer.
144 145 146 147 148 149 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 144 class AuthConfig < Struct.new( :auth_type, :credential_provider_identifier) SENSITIVE = [] include Aws::Structure end |