Class: Aws::AppIntegrationsService::Types::CreateEventIntegrationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppIntegrationsService::Types::CreateEventIntegrationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appintegrationsservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
The description of the event integration.
-
#event_bridge_bus ⇒ String
The EventBridge bus.
-
#event_filter ⇒ Types::EventFilter
The event filter.
-
#name ⇒ String
The name of the event integration.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 540 class CreateEventIntegrationRequest < Struct.new( :name, :description, :event_filter, :event_bridge_bus, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the event integration.
540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 540 class CreateEventIntegrationRequest < Struct.new( :name, :description, :event_filter, :event_bridge_bus, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#event_bridge_bus ⇒ String
The EventBridge bus.
540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 540 class CreateEventIntegrationRequest < Struct.new( :name, :description, :event_filter, :event_bridge_bus, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#event_filter ⇒ Types::EventFilter
The event filter.
540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 540 class CreateEventIntegrationRequest < Struct.new( :name, :description, :event_filter, :event_bridge_bus, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the event integration.
540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 540 class CreateEventIntegrationRequest < Struct.new( :name, :description, :event_filter, :event_bridge_bus, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource. For example, { "tags": "key2":"value2" }.
540 541 542 543 544 545 546 547 548 549 |
# File 'lib/aws-sdk-appintegrationsservice/types.rb', line 540 class CreateEventIntegrationRequest < Struct.new( :name, :description, :event_filter, :event_bridge_bus, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |